LibPamHandle

Struct LibPamHandle 

pub struct LibPamHandle(/* private fields */);
An owned variation of a basic PAM handle.

This is the most basic version of a wrapped PAM handle. It’s mostly used as the inside of the LibPamTransaction, but can also be used to “adopt” a PAM handle created by another library.

If Self::end is not called, this will always call pam_end reporting successful completion.

Implementations

Source

impl LibPamHandle

pub fn end(&mut self, result: Result<()>)

pub fn end_silent(&mut self, result: Result<()>)

Ends the transaction “quietly”, reporting the given result.

On Linux-PAM only, this sets the PAM_DATA_SILENT flag on the value passed to the cleanup callbacks. This conventionally means that this pam_end call is occurring on a forked process, and that a session may still be open on the parent process, and modules “should not treat the call too seriously”.

References
pub fn inner(&self) -> &pam_handle

Gets a reference to the inner PAM handle.

pub fn inner_mut(&mut self) -> &mut pam_handle

Gets a mutable reference to the inner PAM handle.